@@ -13,8 +13,12 @@ use warnings::register;
 use 5.001;
 
 use vars qw($VERSION $DATE);
-$VERSION = '0.03';
-$DATE = '2003/07/07';
+$VERSION = '0.04';
+$DATE = '2003/07/31';
+
+use attributes qw(reftype);
+# use SelfLoader;
+
 
 ########
 # Create new FileType Format Parser
@@ -35,7 +39,11 @@ sub new
     my $self = bless {}, $class;
     $self->{options} = $options_p;
 
+    ######
+    # Validate the file
+    #
     my $file = $self->{options}->{file};
+    $self->{options}->{file} = $file;
     unless ( $file ) {
         $self->{fh} = '';
         $self->{options}->{flag} = '';
@@ -46,15 +54,18 @@ sub new
     # Open the table file
     #    
     my ($fh,$flag);
-    if( ref($file) eq 'GLOB' ) {
+    if( ref($file) && attributes::reftype($file) eq 'GLOB') {
         $fh = $file;
         $self->{options}->{file} = '';
         $self->{options}->{flag} = '<';
         $flag = '<';
     }
     else {
-        $flag = $self->{options}->{flag};
+        $flag = $self->{options}->{flag};   
         $flag = '<' unless $flag;
+        $flag =~ s/^\s*(.*)\s*$/$1/;
+        $file =~ s/^\s*(.*)\s*$/$1/;
+        $self->{options}->{flag} = $flag;
         unless (open( $fh, "$flag $file" )) {
             warn "Cannot open table\n\t$file\n";
             return undef;
@@ -144,14 +155,137 @@ sub finish
             warn("Could not close\n\t$self->{options}->{'file'}\n");
             return 0;
         }
-        $self->{fh} = undef;
     } 
 
+    $self->{fh} = undef;
+    $self->{options}->{column_names}=[];
+
     1;
 }
 
 
-1;
+# 1;
+# __DATA__
+
+
+#######
+#
+# Open file for reading, i.e. SQL select type work
+#
+sub attach
+{
+    my ($class, $table, @args) = @_;
+    
+    $class = ref($class) if( ref($class) );
+
+    ##########
+    # Take care of the options
+    #
+    my $options_p = $args[0] if ref($args[0]);
+    $options_p = { @args } unless( @args % 2 );
+    $options_p = {}  unless ref($options_p);
+    $options_p->{file} = $table;
+    $options_p->{flag} = '<';
+    $class->DataPort::DataFile::new( $options_p );
+
+}
+
+
+#######
+#
+# Open file for reading, i.e. SQL insert type work
+#
+sub append
+{
+    my ($class, $table, @args) = @_;
+    
+    $class = ref($class) if( ref($class) );
+
+    ##########
+    # Take care of the options
+    #
+    my $options_p = $args[0] if ref($args[0]);
+    $options_p = { @args } unless( @args % 2 );
+    $options_p = {}  unless ref($options_p);
+    $options_p->{file} = $table;
+    $options_p->{flag} = '>>';
+    $class->DataPort::DataFile::new( $options_p );
+
+}
+
+
+####
+#
+#
+sub create
+{
+    my ($class, $table, @args) = @_;
+
+    ##########
+    # Take care of the options
+    #
+    my $options_p = $args[0] if ref($args[0]);
+    $options_p = { @args } unless( @args % 2 );
+    $options_p = {}  unless ref($options_p);
+    $options_p->{file} = $table;
+    $options_p->{flag} = '>';
+    $class->DataPort::DataFile::new( $options_p );
+}
+
+
+#########
+# 
+#
+sub decode_record
+{
+    my ($self, $record_p, $fields_sp) = @_;
+
+    ###############
+    # If $fields_sp and $record_p are the same, there
+    # will not be any new copy for $fields_sp and
+    # the $$record_p will not be perserved. It
+    # is one and the same as the $$fields_sp string
+    # and will be converted to the $$fields_sp string
+    #
+    if(!$fields_sp) {
+        $fields_sp = $record_p;
+    }
+    elsif($record_p ne $fields_sp) {
+        $$fields_sp = $$record_p;
+    }
+
+    return undef unless $record_p;
+
+
+    1
+}
+
+
+
+
+#############
+# encode the record
+#
+sub encode_record
+{
+    my ($self, $fields_sp, $record_p) = @_;
+
+    return undef unless $fields_sp;
+
+    ###############
+    # If $record_p and are $fields_sp the same, there
+    # will not be any new copy for $fields_sp and
+    # the $fields_sp will not be perserved. It
+    # is one and the same as the $record_p string
+    # and will be converted to the $record_p string
+    #
+    if(!$record_p) {
+        $record_p = $fields_sp;
+    }
+    elsif($record_p ne $fields_sp) {
+        $$record_p = $$fields_sp;
+    }
+}
 
 
 __END__
