@@ -10,20 +10,20 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/07/07';
+$VERSION = '0.04';
+$DATE = '2003/07/31';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/DataPort_DataFile.pm' => [qw(0.03 2003/07/07), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2003/07/07), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2003/07/07), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2003/07/07), 'generated, replaces 0.02'],
-    'lib/DataPort/DataFile.pm' => [qw(0.03 2003/07/07), 'revised 0.02'],
-    't/DataPort/DataFile.d' => [qw(0.05 2003/07/07), 'revised 0.04'],
-    't/DataPort/DataFile.pm' => [qw(0.04 2003/07/07), 'revised 0.03'],
-    't/DataPort/DataFile.t' => [qw(0.07 2003/07/07), 'revised 0.06'],
+    'lib/Docs/Site_SVD/DataPort_DataFile.pm' => [qw(0.04 2003/07/31), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/07/31), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/07/31), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/07/31), 'generated, replaces 0.03'],
+    'lib/DataPort/DataFile.pm' => [qw(0.04 2003/07/31), 'revised 0.03'],
+    't/DataPort/DataFile.d' => [qw(0.06 2003/07/31), 'revised 0.05'],
+    't/DataPort/DataFile.pm' => [qw(0.01 2003/07/07), 'unchanged'],
+    't/DataPort/DataFile.t' => [qw(0.08 2003/07/31), 'revised 0.07'],
     't/DataPort/DataFile0.tdb' => [qw(0.01 2003/06/08), 'unchanged'],
     't/DataPort/DataFile2.tdb' => [qw(0.01 2003/06/08), 'unchanged'],
     't/DataPort/DataFile2.txt' => [qw(0.01 2003/06/08), 'unchanged'],
@@ -31,8 +31,11 @@ use vars qw(%INVENTORY);
     't/DataPort/DataFile3.txt' => [qw(0.01 2003/06/08), 'unchanged'],
     't/DataPort/DataFile4.tdb' => [qw(0.01 2003/06/08), 'unchanged'],
     't/DataPort/DataFile4.txt' => [qw(0.01 2003/06/08), 'unchanged'],
-    't/DataPort/DataFile5.txt' => [qw(0.02 2003/06/23), 'unchanged'],
-    't/DataPort/DataFileI.pm' => [qw(0.01 2003/06/23), 'unchanged'],
+    't/DataPort/DataFile5.txt' => [qw(0.03 2003/07/31), 'revised 0.02'],
+    't/DataPort/DataFileI.pm' => [qw(0.02 2003/07/31), 'revised 0.01'],
+    'tlib/File/SmartNL.pm' => [qw(1.11 2003/07/31), 'new'],
+    'tlib/File/Package.pm' => [qw(1.11 2003/07/31), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.12 2003/07/31), 'new'],
 
 );
 
@@ -59,11 +62,11 @@ use vars qw(%INVENTORY);
 
  DataPort::DataFile - Pure Perl API for database files.
 
- Revision: B
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2003/07/07
+ Date: 2003/07/31
 
  Prepared for: General Public 
 
@@ -96,7 +99,7 @@ and streams them to a standard pure Perl API.
 
 =head2 1.3 Document overview.
 
-This document releases DataPort::DataFile version 0.03
+This document releases DataPort::DataFile version 0.04
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -112,8 +115,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/DataPort-DataFile-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/DataPort-DataFile-0.03
+   http://www.softwarediamonds/packages/DataPort-DataFile-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/DataPort-DataFile-0.04
 
 
 Restrictions regarding duplication and license provisions
@@ -181,14 +184,14 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/DataPort_DataFile.pm                       0.03    2003/07/07 revised 0.02
- MANIFEST                                                     0.03    2003/07/07 generated, replaces 0.02
- Makefile.PL                                                  0.03    2003/07/07 generated, replaces 0.02
- README                                                       0.03    2003/07/07 generated, replaces 0.02
- lib/DataPort/DataFile.pm                                     0.03    2003/07/07 revised 0.02
- t/DataPort/DataFile.d                                        0.05    2003/07/07 revised 0.04
- t/DataPort/DataFile.pm                                       0.04    2003/07/07 revised 0.03
- t/DataPort/DataFile.t                                        0.07    2003/07/07 revised 0.06
+ lib/Docs/Site_SVD/DataPort_DataFile.pm                       0.04    2003/07/31 revised 0.03
+ MANIFEST                                                     0.04    2003/07/31 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/07/31 generated, replaces 0.03
+ README                                                       0.04    2003/07/31 generated, replaces 0.03
+ lib/DataPort/DataFile.pm                                     0.04    2003/07/31 revised 0.03
+ t/DataPort/DataFile.d                                        0.06    2003/07/31 revised 0.05
+ t/DataPort/DataFile.pm                                       0.01    2003/07/07 unchanged
+ t/DataPort/DataFile.t                                        0.08    2003/07/31 revised 0.07
  t/DataPort/DataFile0.tdb                                     0.01    2003/06/08 unchanged
  t/DataPort/DataFile2.tdb                                     0.01    2003/06/08 unchanged
  t/DataPort/DataFile2.txt                                     0.01    2003/06/08 unchanged
@@ -196,8 +199,11 @@ consists of the following files:
  t/DataPort/DataFile3.txt                                     0.01    2003/06/08 unchanged
  t/DataPort/DataFile4.tdb                                     0.01    2003/06/08 unchanged
  t/DataPort/DataFile4.txt                                     0.01    2003/06/08 unchanged
- t/DataPort/DataFile5.txt                                     0.02    2003/06/23 unchanged
- t/DataPort/DataFileI.pm                                      0.01    2003/06/23 unchanged
+ t/DataPort/DataFile5.txt                                     0.03    2003/07/31 revised 0.02
+ t/DataPort/DataFileI.pm                                      0.02    2003/07/31 revised 0.01
+ tlib/File/SmartNL.pm                                         1.11    2003/07/31 new
+ tlib/File/Package.pm                                         1.11    2003/07/31 new
+ tlib/Test/Tech.pm                                            1.12    2003/07/31 new
 
 
 =head2 3.3 Changes
@@ -353,21 +359,25 @@ Replace "Test::STD::Scrub" with "Text::Scrub".
 
 Modified PREREQ_PM to reflect new "Text::Scrub" instead of "Test::STD::Scrub".
 
+=item DataPort_DataFile 0.04
+
+Added some more DataPort common functions such as create attach append
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 =back
 
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -395,17 +405,13 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/DataPort-DataFile-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/DataPort-DataFile-0.03
+   http://www.softwarediamonds/packages/DataPort-DataFile-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/DataPort-DataFile-0.04
 
 
 =item Prerequistes.
 
- 'Test::Tech' => '1.09',
- 'Text::Scrub' => '0',
- 'File::Package' => '0',
- 'File::SmartNL' => '0',
- 'File::TestPath' => '0',
+ None.
 
 
 =item Security, privacy, or safety precautions.
@@ -479,15 +485,15 @@ L<DataPort::DataFile|DataPort::DataFile>
 __DATA__
 
 DISTNAME: DataPort-DataFile^
-VERSION : 0.03^
 REPOSITORY_DIR: packages^
+
+VERSION : 0.04^
 FREEZE: 1^
-
 PREVIOUS_DISTNAME:  ^
-REVISION: B^
-PREVIOUS_RELEASE: 0.02^
-AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
+AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
 Pure Perl objectified database interface that streams data from a pure Perl
 objectified data source interface.
@@ -517,15 +523,12 @@ CHANGE2CURRENT:  ^
 AUTO_REVISE:
 lib/DataPort/DataFile.pm
 t/DataPort/DataFile*
+lib/File/SmartNL.pm => tlib/File/SmartNL.pm
+lib/File/Package.pm => tlib/File/Package.pm
+lib/Test/Tech.pm => tlib/Test/Tech.pm
 ^
 
-PREREQ_PM:
-'Test::Tech' => '1.09',
-'Text::Scrub' => '0',
-'File::Package' => '0',
-'File::SmartNL' => '0',
-'File::TestPath' => '0',
-^
+PREREQ_PM:  ^
 
 TESTS:
 t/DataPort/DataFile.t
@@ -685,6 +688,19 @@ Replace "Test::STD::Scrub" with "Text::Scrub".
 
 Modified PREREQ_PM to reflect new "Text::Scrub" instead of "Test::STD::Scrub".
 
+\=item DataPort_DataFile 0.04
+
+Added some more DataPort common functions such as create attach append
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 \=back
 ^
 
